==> haskell-record-dot-preprocessor-0.2.15-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.15
visibility:           public
id:                   record-dot-preprocessor-0.2.15-ICwWKk6q1RXASy9GBmbEGC
key:                  record-dot-preprocessor-0.2.15-ICwWKk6q1RXASy9GBmbEGC
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  c808f61a92a4f9a1e657dab4c366f8f2
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.15

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.15

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.15-ICwWKk6q1RXASy9GBmbEGC
depends:
    base-4.15.1.0 extra-1.7.12-DPTGYhuNp118MPDFhQYU8g ghc-9.0.2
    uniplate-1.6.13-Bz3m6aJYQrB6IKo2ZbSAY5

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-record-dot-preprocessor-0.2.16-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.16
visibility:           public
id:                   record-dot-preprocessor-0.2.16-4Poe7Ya0k03LXIgScaUuSx
key:                  record-dot-preprocessor-0.2.16-4Poe7Ya0k03LXIgScaUuSx
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  aede250f4496f9dc30b1ffe3293074ae
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.16

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.16

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.16-4Poe7Ya0k03LXIgScaUuSx
depends:
    base-4.15.1.0 extra-1.7.13-HYX6gpOPDmAIHqUj1ljVuZ ghc-9.0.2
    uniplate-1.6.13-BOezg2zuMGrKMCjK6N2ijG

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
